import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface RegistryImageConfig extends cdktf.TerraformMetaArguments {
    /**
     * If `true`, the verification of TLS certificates of the server/registry is disabled. Defaults to `false`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#insecure_skip_verify RegistryImage#insecure_skip_verify}
     *
     * @stability stable
     */
    readonly insecureSkipVerify?: boolean | cdktf.IResolvable;
    /**
     * If true, then the Docker image won't be deleted on destroy operation.
     *
     * If this is false, it will delete the image from the docker registry on destroy operation. Defaults to `false`
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#keep_remotely RegistryImage#keep_remotely}
     *
     * @stability stable
     */
    readonly keepRemotely?: boolean | cdktf.IResolvable;
    /**
     * The name of the Docker image.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#name RegistryImage#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * build block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#build RegistryImage#build}
     *
     * @stability stable
     */
    readonly buildAttribute?: RegistryImageBuild[];
}
/**
 * @stability stable
 */
export interface RegistryImageBuildAuthConfig {
    /**
     * the auth token.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#auth RegistryImage#auth}
     *
     * @stability stable
     */
    readonly auth?: string;
    /**
     * the user emal.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#email RegistryImage#email}
     *
     * @stability stable
     */
    readonly email?: string;
    /**
     * hostname of the registry.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#host_name RegistryImage#host_name}
     *
     * @stability stable
     */
    readonly hostName: string;
    /**
     * the identity token.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#identity_token RegistryImage#identity_token}
     *
     * @stability stable
     */
    readonly identityToken?: string;
    /**
     * the registry password.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#password RegistryImage#password}
     *
     * @stability stable
     */
    readonly password?: string;
    /**
     * the registry token.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#registry_token RegistryImage#registry_token}
     *
     * @stability stable
     */
    readonly registryToken?: string;
    /**
     * the server address.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#server_address RegistryImage#server_address}
     *
     * @stability stable
     */
    readonly serverAddress?: string;
    /**
     * the registry user name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#user_name RegistryImage#user_name}
     *
     * @stability stable
     */
    readonly userName?: string;
}
/**
 * @stability stable
 */
export interface RegistryImageBuildUlimit {
    /**
     * soft limit.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#hard RegistryImage#hard}
     *
     * @stability stable
     */
    readonly hard: number;
    /**
     * type of ulimit, e.g. `nofile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#name RegistryImage#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * hard limit.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#soft RegistryImage#soft}
     *
     * @stability stable
     */
    readonly soft: number;
}
/**
 * @stability stable
 */
export interface RegistryImageBuild {
    /**
     * Pairs for build-time variables in the form TODO.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#build_args RegistryImage#build_args}
     *
     * @stability stable
     */
    readonly buildArgs?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * BuildID is an optional identifier that can be passed together with the build request. The.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#build_id RegistryImage#build_id}
     *
     * @stability stable
     */
    readonly buildId?: string;
    /**
     * Images to consider as cache sources.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#cache_from RegistryImage#cache_from}
     *
     * @stability stable
     */
    readonly cacheFrom?: string[];
    /**
     * Optional parent cgroup for the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#cgroup_parent RegistryImage#cgroup_parent}
     *
     * @stability stable
     */
    readonly cgroupParent?: string;
    /**
     * The absolute path to the context folder. You can use the helper function '${path.cwd}/context-dir'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#context RegistryImage#context}
     *
     * @stability stable
     */
    readonly context: string;
    /**
     * The length of a CPU period in microseconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#cpu_period RegistryImage#cpu_period}
     *
     * @stability stable
     */
    readonly cpuPeriod?: number;
    /**
     * Microseconds of CPU time that the container can get in a CPU period.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#cpu_quota RegistryImage#cpu_quota}
     *
     * @stability stable
     */
    readonly cpuQuota?: number;
    /**
     * CPUs in which to allow execution (e.g., `0-3`, `0`, `1`).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#cpu_set_cpus RegistryImage#cpu_set_cpus}
     *
     * @stability stable
     */
    readonly cpuSetCpus?: string;
    /**
     * MEMs in which to allow execution (`0-3`, `0`, `1`).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#cpu_set_mems RegistryImage#cpu_set_mems}
     *
     * @stability stable
     */
    readonly cpuSetMems?: string;
    /**
     * CPU shares (relative weight).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#cpu_shares RegistryImage#cpu_shares}
     *
     * @stability stable
     */
    readonly cpuShares?: number;
    /**
     * Dockerfile file. Defaults to `Dockerfile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#dockerfile RegistryImage#dockerfile}
     *
     * @stability stable
     */
    readonly dockerfile?: string;
    /**
     * A list of hostnames/IP mappings to add to the container’s /etc/hosts file. Specified in the form ["hostname:IP"].
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#extra_hosts RegistryImage#extra_hosts}
     *
     * @stability stable
     */
    readonly extraHosts?: string[];
    /**
     * Always remove intermediate containers.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#force_remove RegistryImage#force_remove}
     *
     * @stability stable
     */
    readonly forceRemove?: boolean | cdktf.IResolvable;
    /**
     * Isolation represents the isolation technology of a container. The supported values are.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#isolation RegistryImage#isolation}
     *
     * @stability stable
     */
    readonly isolation?: string;
    /**
     * User-defined key/value metadata.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#labels RegistryImage#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Set memory limit for build.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#memory RegistryImage#memory}
     *
     * @stability stable
     */
    readonly memory?: number;
    /**
     * Total memory (memory + swap), -1 to enable unlimited swap.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#memory_swap RegistryImage#memory_swap}
     *
     * @stability stable
     */
    readonly memorySwap?: number;
    /**
     * Set the networking mode for the RUN instructions during build.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#network_mode RegistryImage#network_mode}
     *
     * @stability stable
     */
    readonly networkMode?: string;
    /**
     * Do not use the cache when building the image.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#no_cache RegistryImage#no_cache}
     *
     * @stability stable
     */
    readonly noCache?: boolean | cdktf.IResolvable;
    /**
     * Set platform if server is multi-platform capable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#platform RegistryImage#platform}
     *
     * @stability stable
     */
    readonly platform?: string;
    /**
     * Attempt to pull the image even if an older image exists locally.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#pull_parent RegistryImage#pull_parent}
     *
     * @stability stable
     */
    readonly pullParent?: boolean | cdktf.IResolvable;
    /**
     * A Git repository URI or HTTP/HTTPS context URI.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#remote_context RegistryImage#remote_context}
     *
     * @stability stable
     */
    readonly remoteContext?: string;
    /**
     * Remove intermediate containers after a successful build (default behavior).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#remove RegistryImage#remove}
     *
     * @stability stable
     */
    readonly remove?: boolean | cdktf.IResolvable;
    /**
     * The security options.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#security_opt RegistryImage#security_opt}
     *
     * @stability stable
     */
    readonly securityOpt?: string[];
    /**
     * Set an ID for the build session.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#session_id RegistryImage#session_id}
     *
     * @stability stable
     */
    readonly sessionId?: string;
    /**
     * Size of /dev/shm in bytes. The size must be greater than 0.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#shm_size RegistryImage#shm_size}
     *
     * @stability stable
     */
    readonly shmSize?: number;
    /**
     * If true the new layers are squashed into a new image with a single new layer.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#squash RegistryImage#squash}
     *
     * @stability stable
     */
    readonly squash?: boolean | cdktf.IResolvable;
    /**
     * Suppress the build output and print image ID on success.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#suppress_output RegistryImage#suppress_output}
     *
     * @stability stable
     */
    readonly suppressOutput?: boolean | cdktf.IResolvable;
    /**
     * Set the target build stage to build.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#target RegistryImage#target}
     *
     * @stability stable
     */
    readonly target?: string;
    /**
     * Version of the unerlying builder to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#version RegistryImage#version}
     *
     * @stability stable
     */
    readonly version?: string;
    /**
     * auth_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#auth_config RegistryImage#auth_config}
     *
     * @stability stable
     */
    readonly authConfig?: RegistryImageBuildAuthConfig[];
    /**
     * ulimit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html#ulimit RegistryImage#ulimit}
     *
     * @stability stable
     */
    readonly ulimit?: RegistryImageBuildUlimit[];
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html docker_registry_image}.
 *
 * @stability stable
 */
export declare class RegistryImage extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/docker/r/registry_image.html docker_registry_image} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: RegistryImageConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _insecureSkipVerify?;
    /**
     * @stability stable
     */
    get insecureSkipVerify(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set insecureSkipVerify(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetInsecureSkipVerify(): void;
    /**
     * @stability stable
     */
    get insecureSkipVerifyInput(): boolean | cdktf.IResolvable | undefined;
    private _keepRemotely?;
    /**
     * @stability stable
     */
    get keepRemotely(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set keepRemotely(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetKeepRemotely(): void;
    /**
     * @stability stable
     */
    get keepRemotelyInput(): boolean | cdktf.IResolvable | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get sha256Digest(): string;
    private _build?;
    /**
     * @stability stable
     */
    get buildAttribute(): RegistryImageBuild[];
    /**
     * @stability stable
     */
    set buildAttribute(value: RegistryImageBuild[]);
    /**
     * @stability stable
     */
    resetBuildAttribute(): void;
    /**
     * @stability stable
     */
    get buildAttributeInput(): RegistryImageBuild[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
